SeqSigNet Models
================

.. automodule:: sig_networks.seqsignet_bilstm
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: sig_networks.seqsignet_attention_encoder
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: sig_networks.seqsignet_attention_bilstm
   :members:
   :undoc-members:
   :show-inheritance:
